# Copyright (c) 2008-2009 gocept gmbh & co. kg
# See also LICENSE.txt

import sys
import csv

import transaction
import zope.component
import zope.app.component.hooks

import gocept.directory.interfaces
import gocept.directory.customer


def csvreader(stream):
    for row in csv.reader(stream):
        id, title = row
        yield dict(
            id=id.decode('UTF-8'),
            title=title.decode('UTF-8'))


def read(stream, customers):
    """Update customer list from CSV input stream."""
    seen_ids = set()
    for record in csvreader(stream):
        id = record['id']
        seen_ids.add(id)
        if id not in customers:
            customer = gocept.directory.customer.Customer()
            customers[id] = customer
        customer = customers[id]
        customer.id = id
        customer.title = record['title']
    for id in set(customers.keys()) - seen_ids:
        del customers[id]


def run():
    """Entry point for customer import.

    Currently, this needs to be run via zopectl run. A global `root` object
    must be availabe to access the database.

    """
    site = root['directory']
    zope.app.component.hooks.setSite(site)
    customers = zope.component.getUtility(
        gocept.directory.interfaces.ICustomers)
    read(sys.stdin, customers)
    transaction.commit()


if __name__ == '__main__':
    run()
